==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/LimitRangeSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class LimitRangeSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.LimitRangeSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.LimitRangeSpecFluent<A>{
  public LimitRangeSpecFluentImpl() {
  }
  public LimitRangeSpecFluentImpl(io.fabric8.kubernetes.api.model.LimitRangeSpec instance) {
    this.withLimits(instance.getLimits()); 
  }
  private java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> limits =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();
  public A addToLimits(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").add(index >= 0 ? index : _visitables.get("limits").size(), builder);this.limits.add(index >= 0 ? index : limits.size(), builder); return (A)this;
  }
  public A setToLimits(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);
    if (index < 0 || index >= _visitables.get("limits").size()) { _visitables.get("limits").add(builder); } else { _visitables.get("limits").set(index, builder);}
    if (index < 0 || index >= limits.size()) { limits.add(builder); } else { limits.set(index, builder);}
     return (A)this;
  }
  public A addToLimits(io.fabric8.kubernetes.api.model.LimitRangeItem... items) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").add(builder);this.limits.add(builder);} return (A)this;
  }
  public A addAllToLimits(java.util.Collection<io.fabric8.kubernetes.api.model.LimitRangeItem> items) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").add(builder);this.limits.add(builder);} return (A)this;
  }
  public A removeFromLimits(io.fabric8.kubernetes.api.model.LimitRangeItem... items) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").remove(builder);if (this.limits != null) {this.limits.remove(builder);}} return (A)this;
  }
  public A removeAllFromLimits(java.util.Collection<io.fabric8.kubernetes.api.model.LimitRangeItem> items) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").remove(builder);if (this.limits != null) {this.limits.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromLimits(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    if (limits == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> each = limits.iterator();
    final List visitables = _visitables.get("limits");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildLimits instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItem> getLimits() {
    return build(limits);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItem> buildLimits() {
    return build(limits);
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildLimit(java.lang.Integer index) {
    return this.limits.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildFirstLimit() {
    return this.limits.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildLastLimit() {
    return this.limits.get(limits.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildMatchingLimit(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItemBuilder item: limits) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingLimit(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItemBuilder item: limits) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withLimits(java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItem> limits) {
    if (this.limits != null) { _visitables.get("limits").removeAll(this.limits);}
    if (limits != null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>(); for (io.fabric8.kubernetes.api.model.LimitRangeItem item : limits){this.addToLimits(item);}} else { this.limits = null;} return (A) this;
  }
  public A withLimits(io.fabric8.kubernetes.api.model.LimitRangeItem... limits) {
    if (this.limits != null) {this.limits.clear();}
    if (limits != null) {for (io.fabric8.kubernetes.api.model.LimitRangeItem item :limits){ this.addToLimits(item);}} return (A) this;
  }
  public java.lang.Boolean hasLimits() {
    return limits != null && !limits.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> addNewLimit() {
    return new io.fabric8.kubernetes.api.model.LimitRangeSpecFluentImpl.LimitsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> addNewLimitLike(io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    return new io.fabric8.kubernetes.api.model.LimitRangeSpecFluentImpl.LimitsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> setNewLimitLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    return new io.fabric8.kubernetes.api.model.LimitRangeSpecFluentImpl.LimitsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editLimit(java.lang.Integer index) {
    if (limits.size() <= index) throw new RuntimeException("Can't edit limits. Index exceeds size.");
    return setNewLimitLike(index, buildLimit(index));
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editFirstLimit() {
    if (limits.size() == 0) throw new RuntimeException("Can't edit first limits. The list is empty.");
    return setNewLimitLike(0, buildLimit(0));
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editLastLimit() {
    int index = limits.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last limits. The list is empty.");
    return setNewLimitLike(index, buildLimit(index));
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editMatchingLimit(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    int index = -1;
    for (int i=0;i<limits.size();i++) { 
    if (predicate.test(limits.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching limits. No match found.");
    return setNewLimitLike(index, buildLimit(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitRangeSpecFluentImpl that = (LimitRangeSpecFluentImpl) o;
    if (limits != null ? !limits.equals(that.limits) :that.limits != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limits,  super.hashCode());
  }
  public class LimitsNestedImpl<N> extends io.fabric8.kubernetes.api.model.LimitRangeItemFluentImpl<io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<N>> implements io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LimitsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(this, item);
    }
    LimitsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) LimitRangeSpecFluentImpl.this.setToLimits(index,builder.build());
    }
    public N endLimit() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/LimitRangeSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class LimitRangeSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.LimitRangeSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.LimitRangeSpecFluent<A>{
  public LimitRangeSpecFluentImpl() {
  }
  public LimitRangeSpecFluentImpl(io.fabric8.kubernetes.api.model.LimitRangeSpec instance) {
    this.withLimits(instance.getLimits()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> limits =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToLimits(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").add(index >= 0 ? index : _visitables.get("limits").size(), builder);this.limits.add(index >= 0 ? index : limits.size(), builder); return (A)this;
  }
  public A setToLimits(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);
    if (index < 0 || index >= _visitables.get("limits").size()) { _visitables.get("limits").add(builder); } else { _visitables.get("limits").set(index, builder);}
    if (index < 0 || index >= limits.size()) { limits.add(builder); } else { limits.set(index, builder);}
     return (A)this;
  }
  public A addToLimits(io.fabric8.kubernetes.api.model.LimitRangeItem... items) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").add(builder);this.limits.add(builder);} return (A)this;
  }
  public A addAllToLimits(java.util.Collection<io.fabric8.kubernetes.api.model.LimitRangeItem> items) {
    if (this.limits == null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>();}
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").add(builder);this.limits.add(builder);} return (A)this;
  }
  public A removeFromLimits(io.fabric8.kubernetes.api.model.LimitRangeItem... items) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").remove(builder);if (this.limits != null) {this.limits.remove(builder);}} return (A)this;
  }
  public A removeAllFromLimits(java.util.Collection<io.fabric8.kubernetes.api.model.LimitRangeItem> items) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItem item : items) {io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(item);_visitables.get("limits").remove(builder);if (this.limits != null) {this.limits.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromLimits(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    if (limits == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> each = limits.iterator();
    final List visitables = _visitables.get("limits");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildLimits instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItem> getLimits() {
    return build(limits);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItem> buildLimits() {
    return build(limits);
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildLimit(java.lang.Integer index) {
    return this.limits.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildFirstLimit() {
    return this.limits.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildLastLimit() {
    return this.limits.get(limits.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeItem buildMatchingLimit(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItemBuilder item: limits) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingLimit(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.LimitRangeItemBuilder item: limits) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withLimits(java.util.List<io.fabric8.kubernetes.api.model.LimitRangeItem> limits) {
    if (this.limits != null) { _visitables.get("limits").removeAll(this.limits);}
    if (limits != null) {this.limits = new java.util.ArrayList<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder>(); for (io.fabric8.kubernetes.api.model.LimitRangeItem item : limits){this.addToLimits(item);}} else { this.limits = null;} return (A) this;
  }
  public A withLimits(io.fabric8.kubernetes.api.model.LimitRangeItem... limits) {
    if (this.limits != null) {this.limits.clear();}
    if (limits != null) {for (io.fabric8.kubernetes.api.model.LimitRangeItem item :limits){ this.addToLimits(item);}} return (A) this;
  }
  public java.lang.Boolean hasLimits() {
    return limits != null && !limits.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> addNewLimit() {
    return new io.fabric8.kubernetes.api.model.LimitRangeSpecFluentImpl.LimitsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> addNewLimitLike(io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    return new io.fabric8.kubernetes.api.model.LimitRangeSpecFluentImpl.LimitsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> setNewLimitLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
    return new io.fabric8.kubernetes.api.model.LimitRangeSpecFluentImpl.LimitsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editLimit(java.lang.Integer index) {
    if (limits.size() <= index) throw new RuntimeException("Can't edit limits. Index exceeds size.");
    return setNewLimitLike(index, buildLimit(index));
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editFirstLimit() {
    if (limits.size() == 0) throw new RuntimeException("Can't edit first limits. The list is empty.");
    return setNewLimitLike(0, buildLimit(0));
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editLastLimit() {
    int index = limits.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last limits. The list is empty.");
    return setNewLimitLike(index, buildLimit(index));
  }
  public io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<A> editMatchingLimit(java.util.function.Predicate<io.fabric8.kubernetes.api.model.LimitRangeItemBuilder> predicate) {
    int index = -1;
    for (int i=0;i<limits.size();i++) { 
    if (predicate.test(limits.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching limits. No match found.");
    return setNewLimitLike(index, buildLimit(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitRangeSpecFluentImpl that = (LimitRangeSpecFluentImpl) o;
    if (limits != null ? !limits.equals(that.limits) :that.limits != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limits,  additionalProperties,  super.hashCode());
  }
  public class LimitsNestedImpl<N> extends io.fabric8.kubernetes.api.model.LimitRangeItemFluentImpl<io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<N>> implements io.fabric8.kubernetes.api.model.LimitRangeSpecFluent.LimitsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LimitsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.LimitRangeItem item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(this, item);
    }
    LimitsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.LimitRangeItemBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LimitRangeItemBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) LimitRangeSpecFluentImpl.this.setToLimits(index,builder.build());
    }
    public N endLimit() {
      return and();
    }
    
  }
  
}
